@@ -1,8 +1,6 @@
 package t::ToolSet::ExportFails2;
 use base 'ToolSet';
 
-ToolSet->export(
-    'Bogus::Module' => [],
-);
+ToolSet->export( 'Bogus::Module' => [], );
 
 1; # return true
